
dynts 0.2 - Development
====================================
* Development moved to github http://github.com/quantmind/dynts
* Added skiplist python implementation.
* Added ccy_ to dependencies.
* **4** dsl functions.
* **53 tests**.


dynts 0.1.a2  - 2010 September 12
====================================
* First release to PyPi in pre-alpha.
 

.. _ccy: http://code.google.com/p/ccy/